import { Server, Socket } from "socket.io";
import { SocketMap } from "../../storage/socketMap";
import CustomRequestException from "../../exceptions/customRequestException";

export default (io: Server, socket: Socket) => {
  socket.on("ping", (callback: Function) => {
    callback();
  });

  socket.on("error", (err) => {
    let status = 500;
    let msg = "Internal Server Error";

    if (err instanceof CustomRequestException) {
      status = err.statusCode;
      msg = err.message;
    }

    if (err instanceof CustomRequestException) {
      console.log("WS Custom Handler", status, msg);
    } else {
      console.log("WS Error Handler", err);
    }

    socket.emit("error", msg);
    socket.leave("home");
  });

  socket.on("disconnecting", () => {
    console.log("socket disconnection: ", socket.id);
    SocketMap.delete(socket.id);
  });

  socket.on("disconnect", () => {});
};
